# chck

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Developer Guide

### Setup

``` sh
# create conda environment
$ mamba env create -f env.yml

# update conda environment
$ mamba env update -n chck --file env.yml
```

### Install

``` sh
pip install -e .

# install from pypi
pip install chck
```

### nbdev

``` sh
# activate conda environment
$ conda activate chck

# make sure the chck package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to the chck package
$ nbdev_prepare
```

### Publishing

``` sh
# publish to pypi
$ nbdev_pypi

# publish to conda
$ nbdev_conda --build_args '-c conda-forge'
$ nbdev_conda --mambabuild --build_args '-c conda-forge -c dsm-72'
```

# Usage

## Installation

Install latest from the GitHub
[repository](https://github.com/dsm-72/chck):

``` sh
$ pip install git+https://github.com/dsm-72/chck.git
```

or from [conda](https://anaconda.org/dsm-72/chck)

``` sh
$ conda install -c dsm-72 chck
```

or from [pypi](https://pypi.org/project/chck/)

``` sh
$ pip install chck
```

## Documentation

Documentation can be found hosted on GitHub
[repository](https://github.com/dsm-72/chck)
[pages](https://dsm-72.github.io/chck/). Additionally you can find
package manager specific guidelines on
[conda](https://anaconda.org/dsm-72/chck) and
[pypi](https://pypi.org/project/chck/) respectively.
